@@ -1888,6 +1888,7 @@ bc_parse_stmt(BcParse* p)
 		case BC_LEX_KW_AUTO:
 		case BC_LEX_KW_DEFINE:
 #if DC_ENABLED
+		case BC_LEX_EXTENDED_REGISTERS:
 		case BC_LEX_EQ_NO_REG:
 		case BC_LEX_COLON:
 		case BC_LEX_EXECUTE:
@@ -2436,6 +2437,7 @@ bc_parse_expr_err(BcParse* p, uint8_t flags, BcParseNext next)
 			case BC_LEX_KW_STREAM:
 			case BC_LEX_KW_ELSE:
 #if DC_ENABLED
+			case BC_LEX_EXTENDED_REGISTERS:
 			case BC_LEX_EQ_NO_REG:
 			case BC_LEX_COLON:
 			case BC_LEX_EXECUTE:
@@ -2462,11 +2464,11 @@ bc_parse_expr_err(BcParse* p, uint8_t flags, BcParseNext next)
 			case BC_LEX_ARRAY_LENGTH:
 #endif // DC_ENABLED
 			{
-#ifndef NDEBUG
+#if BC_DEBUG
 				// We should never get here, even in debug builds.
 				bc_parse_err(p, BC_ERR_PARSE_TOKEN);
 				break;
-#endif // NDEBUG
+#endif // BC_DEBUG
 			}
 		}
 
