@@ -308,9 +308,9 @@ const BcVecFree bc_vec_dtors[] = {
 	bc_vec_free,
 	bc_num_free,
 #if !BC_ENABLE_LIBRARY
-#ifndef NDEBUG
+#if BC_DEBUG
 	bc_func_free,
-#endif // NDEBUG
+#endif // BC_DEBUG
 	bc_slab_free,
 	bc_const_free,
 	bc_result_free,
@@ -1151,47 +1151,60 @@ const uchar dc_parse_insts[] = {
 #if BC_ENABLE_EXTRA_MATH
 	BC_INST_TRUNC,
 #endif // BC_ENABLE_EXTRA_MATH
-	BC_INST_POWER,        BC_INST_MULTIPLY,     BC_INST_DIVIDE,
-	BC_INST_MODULUS,      BC_INST_PLUS,         BC_INST_MINUS,
+	BC_INST_POWER,        BC_INST_MULTIPLY,
+	BC_INST_DIVIDE,       BC_INST_MODULUS,
+	BC_INST_PLUS,         BC_INST_MINUS,
 #if BC_ENABLE_EXTRA_MATH
-	BC_INST_PLACES,       BC_INST_LSHIFT,       BC_INST_RSHIFT,
+	BC_INST_PLACES,       BC_INST_LSHIFT,
+	BC_INST_RSHIFT,
 #endif // BC_ENABLE_EXTRA_MATH
-	BC_INST_INVALID,      BC_INST_INVALID,      BC_INST_INVALID,
-	BC_INST_INVALID,      BC_INST_INVALID,      BC_INST_INVALID,
+	BC_INST_INVALID,      BC_INST_INVALID,
+	BC_INST_INVALID,      BC_INST_INVALID,
+	BC_INST_INVALID,      BC_INST_INVALID,
 	BC_INST_BOOL_OR,      BC_INST_BOOL_AND,
 #if BC_ENABLED
-	BC_INST_INVALID,      BC_INST_INVALID,      BC_INST_INVALID,
-	BC_INST_INVALID,      BC_INST_INVALID,      BC_INST_INVALID,
+	BC_INST_INVALID,      BC_INST_INVALID,
+	BC_INST_INVALID,      BC_INST_INVALID,
+	BC_INST_INVALID,      BC_INST_INVALID,
 #if BC_ENABLE_EXTRA_MATH
-	BC_INST_INVALID,      BC_INST_INVALID,      BC_INST_INVALID,
+	BC_INST_INVALID,      BC_INST_INVALID,
+	BC_INST_INVALID,
 #endif // BC_ENABLE_EXTRA_MATH
 #endif // BC_ENABLED
-	BC_INST_INVALID,      BC_INST_INVALID,      BC_INST_INVALID,
-	BC_INST_REL_GT,       BC_INST_REL_LT,       BC_INST_INVALID,
-	BC_INST_INVALID,      BC_INST_INVALID,      BC_INST_REL_GE,
-	BC_INST_INVALID,      BC_INST_REL_LE,       BC_INST_INVALID,
+	BC_INST_INVALID,      BC_INST_INVALID,
+	BC_INST_INVALID,      BC_INST_REL_GT,
+	BC_INST_REL_LT,       BC_INST_INVALID,
+	BC_INST_INVALID,      BC_INST_INVALID,
+	BC_INST_REL_GE,       BC_INST_INVALID,
+	BC_INST_REL_LE,       BC_INST_INVALID,
 	BC_INST_INVALID,      BC_INST_INVALID,
 #if BC_ENABLED
-	BC_INST_INVALID,      BC_INST_INVALID,      BC_INST_INVALID,
-	BC_INST_INVALID,      BC_INST_INVALID,      BC_INST_INVALID,
-	BC_INST_INVALID,      BC_INST_INVALID,      BC_INST_INVALID,
 	BC_INST_INVALID,      BC_INST_INVALID,
+	BC_INST_INVALID,      BC_INST_INVALID,
+	BC_INST_INVALID,      BC_INST_INVALID,
+	BC_INST_INVALID,      BC_INST_INVALID,
+	BC_INST_INVALID,      BC_INST_INVALID,
+	BC_INST_INVALID,
 #endif // BC_ENABLED
-	BC_INST_IBASE,        BC_INST_OBASE,        BC_INST_SCALE,
+	BC_INST_IBASE,        BC_INST_OBASE,
+	BC_INST_SCALE,
 #if BC_ENABLE_EXTRA_MATH
 	BC_INST_SEED,
 #endif // BC_ENABLE_EXTRA_MATH
-	BC_INST_LENGTH,       BC_INST_PRINT,        BC_INST_SQRT,
-	BC_INST_ABS,          BC_INST_IS_NUMBER,    BC_INST_IS_STRING,
+	BC_INST_LENGTH,       BC_INST_PRINT,
+	BC_INST_SQRT,         BC_INST_ABS,
+	BC_INST_IS_NUMBER,    BC_INST_IS_STRING,
 #if BC_ENABLE_EXTRA_MATH
 	BC_INST_IRAND,
 #endif // BC_ENABLE_EXTRA_MATH
-	BC_INST_ASCIIFY,      BC_INST_MODEXP,       BC_INST_DIVMOD,
-	BC_INST_QUIT,         BC_INST_INVALID,
+	BC_INST_ASCIIFY,      BC_INST_MODEXP,
+	BC_INST_DIVMOD,       BC_INST_QUIT,
+	BC_INST_INVALID,
 #if BC_ENABLE_EXTRA_MATH
 	BC_INST_RAND,
 #endif // BC_ENABLE_EXTRA_MATH
-	BC_INST_MAXIBASE,     BC_INST_MAXOBASE,     BC_INST_MAXSCALE,
+	BC_INST_MAXIBASE,     BC_INST_MAXOBASE,
+	BC_INST_MAXSCALE,
 #if BC_ENABLE_EXTRA_MATH
 	BC_INST_MAXRAND,
 #endif // BC_ENABLE_EXTRA_MATH
@@ -1199,17 +1212,21 @@ const uchar dc_parse_insts[] = {
 #if BC_ENABLED
 	BC_INST_INVALID,
 #endif // BC_ENABLED
-	BC_INST_LEADING_ZERO, BC_INST_PRINT_STREAM, BC_INST_INVALID,
-	BC_INST_REL_EQ,       BC_INST_INVALID,      BC_INST_EXECUTE,
-	BC_INST_PRINT_STACK,  BC_INST_CLEAR_STACK,  BC_INST_INVALID,
-	BC_INST_STACK_LEN,    BC_INST_DUPLICATE,    BC_INST_SWAP,
-	BC_INST_POP,          BC_INST_INVALID,      BC_INST_INVALID,
+	BC_INST_LEADING_ZERO, BC_INST_PRINT_STREAM,
+	BC_INST_INVALID,      BC_INST_EXTENDED_REGISTERS,
+	BC_INST_REL_EQ,       BC_INST_INVALID,
+	BC_INST_EXECUTE,      BC_INST_PRINT_STACK,
+	BC_INST_CLEAR_STACK,  BC_INST_INVALID,
+	BC_INST_STACK_LEN,    BC_INST_DUPLICATE,
+	BC_INST_SWAP,         BC_INST_POP,
+	BC_INST_INVALID,      BC_INST_INVALID,
 	BC_INST_INVALID,
 #if BC_ENABLE_EXTRA_MATH
 	BC_INST_INVALID,
 #endif // BC_ENABLE_EXTRA_MATH
-	BC_INST_INVALID,      BC_INST_INVALID,      BC_INST_INVALID,
-	BC_INST_PRINT_POP,    BC_INST_NQUIT,        BC_INST_EXEC_STACK_LEN,
+	BC_INST_INVALID,      BC_INST_INVALID,
+	BC_INST_INVALID,      BC_INST_PRINT_POP,
+	BC_INST_NQUIT,        BC_INST_EXEC_STACK_LEN,
 	BC_INST_SCALE_FUNC,   BC_INST_INVALID,
 };
 #endif // DC_ENABLED
