@@ -223,7 +223,7 @@ bc_parse_reset(BcParse* p)
 	if (BC_ERR(vm->status)) BC_JMP;
 }
 
-#ifndef NDEBUG
+#if BC_DEBUG
 void
 bc_parse_free(BcParse* p)
 {
@@ -244,7 +244,7 @@ bc_parse_free(BcParse* p)
 
 	bc_lex_free(&p->l);
 }
-#endif // NDEBUG
+#endif // BC_DEBUG
 
 void
 bc_parse_init(BcParse* p, BcProgram* prog, size_t func)
